====================
aws-session-recorder
====================


.. image:: https://img.shields.io/pypi/v/aws_session_recorder.svg
        :target: https://pypi.python.org/pypi/aws_session_recorder

.. image:: https://img.shields.io/travis/RyanJarv/aws_session_recorder.svg
        :target: https://travis-ci.com/RyanJarv/aws_session_recorder

.. image:: https://readthedocs.org/projects/aws-session-recorder/badge/?version=latest
        :target: https://aws-session-recorder.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status




AWS session that records discovered resources to a database


* Free software: BSD license
* Documentation: https://aws-session-recorder.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
